Release history
===============

.. currentmodule:: outcome

.. towncrier release notes start

Outcome 0.1.1a0 (2018-03-24)
----------------------------

Features
~~~~~~~~

- Added florps (`#123 <https://github.com/python-trio/outcome/issues/123>`__)


Outcome 0.1.0a0 (2018-03-24)
----------------------------

No significant changes.
